@@ -1,3 +1,10 @@
+__all__ = [
+    'json_deserialize',
+    'dic2class',
+    'set_value',
+    ]
+
+
 import json
 
 def json_deserialize(json_data, obj):
