@@ -1,3 +1,8 @@
+
+__all__ = [
+    'getCurrentIP',
+    ]
+
 import socket
 
 
